@@ -81,16 +81,12 @@ License\".")
      "A golden-section minimum finder")
     ((math primes)
      "Functions related to prime numbers and factorization")
-    ((math rationalize)
-     "Working with fractions")
     ((os process)
      "Spawning processes and capturing their output")
     ((scheme documentation)
      "Macros to define different kinds of variables with documentation")
     ((scheme kwargs)
      "Defining functions with flexible keyword arguments")
-    ((scheme session)
-     "A more featureful " (code "(ice-9 session)"))
     ((search basic)
      "Classic search functions")
     ((statprof)
@@ -151,4 +147,6 @@ License\".")
     ((sxml ssax input-parse) . "http://ssax.sourceforge.net/")
     ((htmlprag) . "http://neilvandyke.org/htmlprag/")))
 
+(define *scripts* '())
+
 ;; arch-tag: e493ad42-ad58-451c-a2d6-b17ba6c1d1d0
